==> wls-plugin-1.2.1-sources.jar: com/xebialabs/deployit/plugin/wls/step/create-server.py <==
#
# Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
#
# Your use of Xebialabs Software and Documentation is subject to the Personal
# License Agreement.
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# ‚ÄúDocumentation‚Äù means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the Xebialabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to  (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys

sys.argv.pop(0)
user = sys.argv.pop(0)
password = sys.argv.pop(0)
url = sys.argv.pop(0)
servername = sys.argv.pop(0)
port = int(sys.argv.pop(0))
hostname = sys.argv.pop(0)

connect(user, password, url)

hostnamebean = getMBean('/Machines/' + hostname)



if hostnamebean is None:
	# create a unix machine on passive host if it is not found
	edit()
	startEdit()
	cd('/')
	cmo.createUnixMachine(hostname)
	cd('/Machines/' + hostname + '/NodeManager/' + hostname)
	cmo.setNMType('Plain')
	cmo.setListenAddress(hostname)
	hostnamebean = getMBean('/Machines/' + hostname)
	save()
	activate(block="true")

edit()
startEdit()
cd('/')
cmo.createServer(servername)

cd('/Servers/' + servername)
cmo.setListenPort(port)
cmo.setMachine(hostnamebean)
cmo.setListenAddress(hostname)

cd('/Servers/' + servername + '/SSL/' + servername)
cmo.setEnabled(false)

save()	
activate(block="true")
print "Created Server : " + servername + " successfully."
disconnect()

exit()

==> wls-plugin-1.3.2-sources.jar: com/xebialabs/deployit/plugin/wls/step/create-server.py <==
#
# Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys

scriptname = sys.argv.pop(0)
user = sys.argv.pop(0)
password = sys.argv.pop(0)
url = sys.argv.pop(0)
servername = sys.argv.pop(0)
port = int(sys.argv.pop(0))
hostname = sys.argv.pop(0)

print "Connecting to WebLogic"
connect(user, password, url)
edit()
startEdit()

hostnamebean = getMBean('/Machines/' + hostname)
if hostnamebean is None:
	print "Creating Machine " + hostname
	# create a unix machine on passive host if it is not found
	cd('/')
	cmo.createUnixMachine(hostname)
	cd('/Machines/' + hostname + '/NodeManager/' + hostname)
	cmo.setNMType('Plain')
	cmo.setListenAddress(hostname)
	hostnamebean = getMBean('/Machines/' + hostname)

print "Creating server " + servername
cd('/')
cmo.createServer(servername)

cd('/Servers/' + servername)
cmo.setListenPort(port)
cmo.setMachine(hostnamebean)
cmo.setListenAddress(hostname)

cd('/Servers/' + servername + '/SSL/' + servername)
cmo.setEnabled(false)

print "Saving configuration"
save()
disconnect('true')
exit('y')
